@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * AgingTV - film-aging effect.
  * Copyright (C) 2001-2002 FUKUCHI Kentaro
@@ -24,13 +24,17 @@ static int aging_mode;
 
 static void coloraging(RGB32 *src, RGB32 *dest)
 {
+	static int c = 0x18;
 	RGB32 a, b;
 	int i;
 
+	c -= (int)(inline_fastrand())>>28;
+	if(c < 0) c = 0;
+	if(c > 0x18) c = 0x18;
 	for(i=0; i<video_area; i++) {
 		a = *src++;
 		b = (a & 0xfcfcfc)>>2;
-		*dest++ = a - b + 0x181818 + ((fastrand()>>8)&0x101010);
+		*dest++ = a - b + (c|(c<<8)|(c<<16)) + ((inline_fastrand()>>8)&0x101010);
 	}
 }
 
@@ -163,7 +167,7 @@ static void pits(RGB32 *dest)
 	}
 }
 
-effect *agingRegister()
+effect *agingRegister(void)
 {
 	effect *entry;
 
@@ -179,7 +183,7 @@ effect *agingRegister()
 	return entry;
 }
 
-static void aging_mode_switch()
+static void aging_mode_switch(void)
 {
 	switch(aging_mode) {
 		default:
@@ -193,7 +197,7 @@ static void aging_mode_switch()
 		area_scale = 1;
 }
 
-static int start()
+static int start(void)
 {
 	aging_mode = 0;
 	aging_mode_switch();
@@ -202,7 +206,7 @@ static int start()
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	state = 0;
 
