@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * FireTV - clips incoming objects and burn them.
  * Copyright (C) 2001-2002 FUKUCHI Kentaro
@@ -37,7 +37,7 @@ static int setBackground(RGB32 *src)
 	return 0;
 }
 
-static void makePalette()
+static void makePalette(void)
 {
 	int i, r, g, b;
 
@@ -55,7 +55,7 @@ static void makePalette()
 	}
 }
 
-effect *fireRegister()
+effect *fireRegister(void)
 {
 	effect *entry;
 	
@@ -81,7 +81,7 @@ effect *fireRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	image_set_threshold_y(MAGIC_THRESHOLD);
 	memset(buffer, 0, video_area);
@@ -91,7 +91,7 @@ static int start()
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	state = 0;
 	return 0;
