@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * LifeTV - Play John Horton Conway's `Life' game with video input.
  * Copyright (C) 2001-2002 FUKUCHI Kentaro
@@ -17,18 +17,18 @@
 static int start(void);
 static int stop(void);
 static int draw(RGB32 *src, RGB32 *dest);
-static int event();
+static int event(SDL_Event *event);
 
 static char *effectname = "LifeTV";
 static int stat;
 static unsigned char *field, *field1, *field2;
 
-static void clear_field()
+static void clear_field(void)
 {
 	memset(field1, 0, video_area);
 }
 
-effect *lifeRegister()
+effect *lifeRegister(void)
 {
 	effect *entry;
 	
@@ -52,7 +52,7 @@ effect *lifeRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	image_set_threshold_y(40);
 	field1 = field;
@@ -63,7 +63,7 @@ static int start()
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	stat = 0;
 	return 0;
