@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * MosaicTV - censors incoming objects
  * Copyright (C) 2001-2002 FUKUCHI Kentaro
@@ -18,7 +18,7 @@
 static int start(void);
 static int stop(void);
 static int draw(RGB32 *src, RGB32 *dest);
-static int event();
+static int event(SDL_Event *event);
 
 static char *effectname = "MosaicTV";
 static int stat;
@@ -32,7 +32,7 @@ static int setBackground(RGB32 *src)
 	return 0;
 }
 
-effect *mosaicRegister()
+effect *mosaicRegister(void)
 {
 	effect *entry;
 	
@@ -50,7 +50,7 @@ effect *mosaicRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	image_set_threshold_y(MAGIC_THRESHOLD);
 	bgIsSet = 0;
@@ -59,7 +59,7 @@ static int start()
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	stat = 0;
 	return 0;
