@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * nervousTV - The name says it all...
  * Copyright (C) 2002 TANNENBAUM Edo
@@ -22,7 +22,7 @@
 static int start(void);
 static int stop(void);
 static int draw(RGB32 *src, RGB32 *dest);
-static int event();
+static int event(SDL_Event *event);
 
 static char *effectname = "NervousTV";
 static int state = 0;
@@ -35,13 +35,12 @@ static int timer;
 static int stride;
 static int readplane;
 
-effect *nervousRegister()
+effect *nervousRegister(void)
 {
 	effect *entry;
 
 	entry = (effect *)malloc(sizeof(effect));
 	if(entry == NULL) {
-		free(buffer);
 		return NULL;
 	}
 
@@ -54,7 +53,7 @@ effect *nervousRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	int i;
 
@@ -74,7 +73,7 @@ static int start()
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	if(state) {
 		if(buffer)
