@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * NoiseTV - make incoming objects noisy.
  * Copyright (C) 2001-2002 FUKUCHI Kentaro
@@ -14,7 +14,7 @@
 static int start(void);
 static int stop(void);
 static int draw(RGB32 *src, RGB32 *dest);
-static int event();
+static int event(SDL_Event *event);
 
 static char *effectname = "NoiseTV";
 static int stat;
@@ -28,7 +28,7 @@ static int setBackground(RGB32 *src)
 	return 0;
 }
 
-effect *noiseRegister()
+effect *noiseRegister(void)
 {
 	effect *entry;
 	
@@ -46,7 +46,7 @@ effect *noiseRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	image_set_threshold_y(40);
 	bgIsSet = 0;
@@ -55,7 +55,7 @@ static int start()
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	stat = 0;
 	return 0;
