@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * PuzzleTV - separates the image into blocks and scrambles them.
  *            The blocks can be moved interactively.
@@ -17,7 +17,7 @@
 static int start(void);
 static int stop(void);
 static int draw(RGB32 *src, RGB32 *dest);
-static int event();
+static int event(SDL_Event *event);
 
 #define BLOCKSIZE 80
 #define SLIDING_INTERVAL 30
@@ -51,7 +51,7 @@ static void blockSetSrcOffset(int i);
 static void moveBlock(RGB32 *src, RGB32 *dest);
 static void autoSolve(void);
 
-effect *puzzleRegister()
+effect *puzzleRegister(void)
 {
 	effect *entry;
 	int x, y;
@@ -98,7 +98,7 @@ effect *puzzleRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	int i, a, b, c;
 
@@ -130,7 +130,7 @@ static int start()
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	stat = 0;
 	return 0;
