@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * QuarkTV - motion disolver.
  * Copyright (C) 2001-2002 FUKUCHI Kentaro
@@ -24,7 +24,7 @@ static RGB32 *buffer;
 static RGB32 *planetable[PLANES];
 static int plane;
 
-effect *quarkRegister()
+effect *quarkRegister(void)
 {
 	effect *entry;
 
@@ -42,7 +42,7 @@ effect *quarkRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	int i;
 	
@@ -59,7 +59,7 @@ static int start()
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	if(state) {
 		if(buffer) {
@@ -80,7 +80,7 @@ static int draw(RGB32 *src, RGB32 *dest)
 	memcpy(planetable[plane], src, video_area * PIXEL_SIZE);
 
 	for(i=0; i<video_area; i++) {
-		cf = (plane + (inline_fastrand()>>24))&(PLANES-1);
+		cf = (inline_fastrand()>>24)&(PLANES-1);
 		dest[i] = (planetable[cf])[i];
 		/* The reason why I use high order 8 bits is written in utils.c
 		(or, 'man rand') */
