@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2002 FUKUCHI Kentarou
+ * Copyright (C) 2001-2006 FUKUCHI Kentarou
  *
  * RandomDotStereoTV - makes random dot stereogram.
  * Copyright (C) 2002 FUKUCHI Kentarou
@@ -16,14 +16,14 @@
 static int start(void);
 static int stop(void);
 static int draw(RGB32 *src, RGB32 *dest);
-static int event();
+static int event(SDL_Event *event);
 
 static char *effectname = "RandomDotStereoTV";
 static int stat;
 static int stride = 40;
 static int method = 0;
 
-effect *rdsRegister()
+effect *rdsRegister(void)
 {
 	effect *entry;
 	
@@ -41,13 +41,13 @@ effect *rdsRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	stat = 1;
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	stat = 0;
 	return 0;
