@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * revTV based on Rutt-Etra Video Synthesizer 1974?
  *
@@ -22,10 +22,10 @@
 #include "EffecTV.h"
 #include "utils.h"
 
-static int event();
 static int start(void);
 static int stop(void);
 static int draw(RGB32 *src, RGB32 *dest);
+static int event(SDL_Event *event);
 
 static int vgrabtime=1;
 static int vgrab=0;
@@ -39,7 +39,7 @@ static int state = 0;
 
 static void vasulka(RGB32 *src, RGB32 *dst, int srcx, int srcy, int dstx, int dsty, int w, int h);
 
-effect *revRegister()
+effect *revRegister(void)
 {
 	effect *entry;
 
@@ -55,13 +55,13 @@ effect *revRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	state = 1;
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	state = 0;
 	return 0;
