@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * rndmTV Random noise based on video signal
  * (c)2002 Ed Tannenbaum <et@et-arts.com>
@@ -12,10 +12,10 @@
 #include "EffecTV.h"
 #include "utils.h"
 
-static int event();
 static int start(void);
 static int stop(void);
 static int draw(RGB32 *src, RGB32 *dest);
+static int event(SDL_Event *event);
 
 static int rgrabtime=1;
 static int rgrab=0;
@@ -25,7 +25,7 @@ static int rmode=1;
 static char *effectname = "RndmTV";
 static int state = 0;
 
-effect *rndmRegister()
+effect *rndmRegister(void)
 {
 	effect *entry;
 
@@ -41,13 +41,13 @@ effect *rndmRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	state = 1;
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	state = 0;
 	return 0;
