@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * SimuraTV - color distortion and mirrored image effector
  * Copyright (C) 2001-2002 FUKUCHI Kentaro
@@ -15,7 +15,7 @@
 static int start(void);
 static int stop(void);
 static int draw(RGB32 *src, RGB32 *dest);
-static int event();
+static int event(SDL_Event *event);
 
 static char *effectname = "SimuraTV";
 static int stat;
@@ -55,7 +55,7 @@ static void mirror_ur(RGB32 *, RGB32 *);
 static void mirror_dl(RGB32 *, RGB32 *);
 static void mirror_dr(RGB32 *, RGB32 *);
 
-effect *simuraRegister()
+effect *simuraRegister(void)
 {
 	effect *entry;
 	int i;
@@ -87,13 +87,13 @@ effect *simuraRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	stat = 1;
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	stat = 0;
 	return 0;
