@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * SparkTV - spark effect.
  * Copyright (C) 2001-2002 FUKUCHI Kentaro
@@ -16,12 +16,12 @@
 static int start(void);
 static int stop(void);
 static int draw(RGB32 *src, RGB32 *dest);
-static int event();
+static int event(SDL_Event *event);
 
 static char *effectname = "SparkTV";
 static int stat;
 static int bgIsSet = 0;
-static int mode;
+static int mode = 0;
 
 struct shortvec {
 	int x1;
@@ -335,7 +335,7 @@ static int setBackground(RGB32 *src)
 	return 0;
 }
 
-effect *sparkRegister()
+effect *sparkRegister(void)
 {
 	effect *entry;
 
@@ -353,7 +353,7 @@ effect *sparkRegister()
 	return entry;
 }
 
-static int start()
+static int start(void)
 {
 	int i;
 	
@@ -366,13 +366,12 @@ static int start()
 	sparks_head = 0;
 	image_set_threshold_y(40);
 	bgIsSet = 0;
-	mode = 0;
 
 	stat = 1;
 	return 0;
 }
 
-static int stop()
+static int stop(void)
 {
 	stat = 0;
 	return 0;
