@@ -1,4 +1,7 @@
 /*
+ * EffecTV - Realtime Digital Video Effector
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
+ *
  * Plugin for EffecTV by Fukuchi Kentarou
  * Written by clifford smith <nullset@dookie.net>
  * 
@@ -43,7 +46,7 @@ static int mapFromT(int x,int y, int t) {
   return xd + yd*video_width;
 }
 
-effect *TransFormRegister()
+effect *TransFormRegister(void)
 {
 	effect *entry;
 
@@ -61,7 +64,7 @@ effect *TransFormRegister()
 	return entry;
 }
 
-static void SquareTableInit()
+static void SquareTableInit(void)
 {
 	const int size = 16;
 	int x, y, tx, ty;
@@ -87,7 +90,7 @@ static void SquareTableInit()
 	}
 }
 
-static int start()
+static int start(void)
 {
   int x,y,i;
 //   int xdest,ydest;
@@ -114,7 +117,7 @@ static int start()
   return 0;
 }
 
-static int stop()
+static int stop(void)
 {
   int i;
 
