@@ -698,6 +698,57 @@ static struct CHANLIST pal_australia[] = {
     { "69",	814250 },
 };
 
+static struct CHANLIST pal_australia_optus[] = {
+   { "1",  138250 },
+   { "2",  147250 },
+   { "3",  154250 },
+   { "4",  161250 },
+   { "5",  168250 },
+   { "6",  175250 },
+   { "7",  182250 },
+   { "8",  189250 },
+   { "9",  196250 },
+   { "10", 209250 },
+   { "11", 216250 },
+   { "12", 224250 },
+   { "13", 231250 },
+   { "14", 238250 },
+   { "15", 245250 },
+   { "16", 252250 },
+   { "17", 259250 },
+   { "18", 266250 },
+   { "19", 273250 },
+   { "20", 280250 },
+   { "21", 287250 },
+   { "22", 294250 },
+   { "23", 303250 },
+   { "24", 310250 },
+   { "25", 317250 },
+   { "26", 324250 },
+   { "27", 338250 },
+   { "28", 345250 },
+   { "29", 352250 },
+   { "30", 359250 },
+   { "31", 366250 },
+   { "32", 373250 },
+   { "33", 380250 },
+   { "34", 387250 },
+   { "35", 394250 },
+   { "36", 401250 },
+   { "37", 408250 },
+   { "38", 415250 },
+   { "39", 422250 },
+   { "40", 429250 },
+   { "41", 436250 },
+   { "42", 443250 },
+   { "43", 450250 },
+   { "44", 457250 },
+   { "45", 464250 },
+   { "46", 471250 },
+   { "47", 478250 },
+   { "48", 485250 },
+ };
+
 /* --------------------------------------------------------------------- */
 /* europe                                                                */
 
@@ -1225,6 +1276,7 @@ struct CHANLISTS chanlists[] = {
     { "southafrica",      pal_bcast_za,      CHAN_COUNT(pal_bcast_za)      },
     { "argentina",        argentina,         CHAN_COUNT(argentina)         },
     { "canada-cable",     ntsc_cable_ca,     CHAN_COUNT(ntsc_cable_ca)     },
+    { "australia-optus",        pal_australia_optus,     CHAN_COUNT(pal_australia_optus)     },
     { NULL, NULL, 0 } /* EOF */
 };
 
@@ -1246,6 +1298,7 @@ struct STRTAB chanlist_names[] = {
     { 13, "southafrica" },
     { 14, "argentina" },
     { 15, "canada-cable" },
+    {  16, "australia-optus" },
     { -1, NULL }
 };
 
