@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * image.c: utilities for image processing.
  *
@@ -18,7 +18,7 @@ static unsigned char *diff;
 static unsigned char *diff2;
 
 /* Initializer is called from utils_init(). */
-int image_init()
+int image_init(void)
 {
 	stretching_buffer = (RGB32 *)malloc(video_area * sizeof(RGB32));
 	background = (RGB32 *)malloc(video_area * sizeof(RGB32));
@@ -32,7 +32,7 @@ int image_init()
 	return 0;
 }
 
-void image_end()
+void image_end(void)
 {
 	free(stretching_buffer);
 	free(background);
@@ -73,7 +73,7 @@ void image_stretch(RGB32 *src, int src_width, int src_height,
 	}
 }
 
-static void image_stretch_to_screen_double()
+static void image_stretch_to_screen_double(void)
 {
 	int x, y;
 	RGB32 *src, *dest1, *dest2;
@@ -98,7 +98,7 @@ static void image_stretch_to_screen_double()
 	}
 }
 
-void image_stretch_to_screen()
+void image_stretch_to_screen(void)
 {
 	if(screen_scale == 2) {
 		image_stretch_to_screen_double();
@@ -350,6 +350,47 @@ unsigned char *image_y_under(RGB32 *src)
 	return diff;
 }
 
+/* tiny edge detection */
+unsigned char *image_edge(RGB32 *src)
+{
+	int x, y;
+	unsigned char *p, *q;
+	int r, g, b;
+	int ar, ag, ab;
+	int w;
+
+	p = (unsigned char *)src;
+	q = diff2;
+	w = video_width * sizeof(RGB32);
+
+	for(y=0; y<video_height - 1; y++) {
+		for(x=0; x<video_width - 1; x++) {
+			b = p[0];
+			g = p[1];
+			r = p[2];
+			ab = abs(b - p[4]);
+			ag = abs(g - p[5]);
+			ar = abs(r - p[6]);
+			ab += abs(b - p[w]);
+			ag += abs(g - p[w+1]);
+			ar += abs(r - p[w+2]);
+			b = ab+ag+ar;
+			if(b > y_threshold) {
+				*q = 255;
+			} else {
+				*q = 0;
+			}
+			q++;
+			p += 4;
+		}
+		p += 4;
+		*q++ = 0;
+	}
+	memset(q, 0, video_width);
+
+	return diff2;
+}
+
 /* horizontal flipping */
 void image_hflip(RGB32 *src, RGB32 *dest, int width, int height)
 {
@@ -363,3 +404,4 @@ void image_hflip(RGB32 *src, RGB32 *dest, int width, int height)
 		src += width * 2;
 	}
 }
+
