@@ -1,6 +1,6 @@
 /*
  * EffecTV - Realtime Digital Video Effector
- * Copyright (C) 2001-2003 FUKUCHI Kentaro
+ * Copyright (C) 2001-2006 FUKUCHI Kentaro
  *
  * video.h: header for video manager
  *
@@ -17,9 +17,8 @@ typedef struct _normlist
 	int type;
 } normlist;
 
-extern v4ldevice vd;
-extern int hastuner;
-extern int horizontal_flip;
+extern int video_hasTuner;
+extern int video_horizontalFlip;
 extern int video_width;
 extern int video_height;
 extern int video_area;
@@ -41,8 +40,8 @@ void video_change_hue(int);
 void video_change_color(int);
 void video_change_contrast(int);
 void video_change_whiteness(int);
-
-#define video_getformat() (vd.mmap.format)
+int video_change_channel(int channel);
+int video_retry(void);
 
 int videox_getnorm(const char *name);
 int videox_getfreq(const char *name);
